jQuery(document).ready(function($) {
    /*
     * Pagination
     */

    /*
     * Builds Pagination Links
     *
     * @param {int} current_page
     * @param {int} total_page
     * @param {int} gallery_id
     * @param {string} layout_type
     * @return {string}
     */
    function wopgld_build_pagination_html(current_page, total_page, post_id, layout_type, next_arrow, prev_arrow) {
        var pagination_html = '';
        if (current_page > 1) {
            pagination_html += '<li class="wopgld-previous-page-wrap"><a href="javascript:void(0);" class="wopgld-previous-page" data-total-page="' + total_page + '" data-layout-type="' + layout_type + '" data-post-id="' + post_id + '"  data-prev-arrow="' + prev_arrow + '" data-next-arrow="' + next_arrow + '">' + prev_arrow + '</a></li>';
        }
        var upper_limit = current_page + 2;
        var lower_limit = current_page - 2;
        if (upper_limit > total_page) {
            upper_limit = total_page;
        }

        if (lower_limit < 1) {
            lower_limit = 1;
        }
        if (upper_limit - lower_limit < 5 && upper_limit - 4 >= 1) {
            lower_limit = upper_limit - 4;
        }
        if (upper_limit < 5 && total_page >= 5) {
            upper_limit = 5;
        }

        for (var page_count = lower_limit; page_count <= upper_limit; page_count++) {
            var page_class = (current_page === page_count) ? 'wopgld-current-page wopgld-page-link' : 'wopgld-page-link';
            pagination_html += '<li><a href="javascript:void(0);" data-total-page="' + total_page + '" data-page-number="' + page_count + '" class="' + page_class + '" data-layout-type="' + layout_type + '" data-post-id="' + post_id + '" data-prev-arrow="' + prev_arrow + '" data-next-arrow="' + next_arrow + '">' + page_count + '</a></li>';
        }
        if (current_page < total_page) {
            pagination_html += '<li class="wopgld-next-page-wrap"><a href="javascript:void(0);" data-total-page="' + total_page + '" class="wopgld-next-page" data-layout-type="' + layout_type + '" data-post-id="' + post_id + '" data-prev-arrow="' + prev_arrow + '" data-next-arrow="' + next_arrow + '">' + next_arrow + '</a></li>';
        }
        return pagination_html;
    }

    $('body').on('click', '.wopgld-page-link', function() {
        var selector = $(this);
        selector.closest('.wopgld-pagination-block').find('.wopgld-page-link').removeClass('wopgld-current-page');
        $(this).addClass('wopgld-current-page');
        var layout_type = $(this).data('layout-type');
        var page_num = $(this).data('page-number');
        var post_id = $(this).data('post-id');
        var total_page = $(this).data('total-page');
        var next_arrow = $(this).data('next-arrow');
        var prev_arrow = $(this).data('prev-arrow');
        $.ajax({
            type: 'post',
            url: wopgld_frontend_js_params.ajax_url,
            data: {
                action: 'wopgld_pagination_action',
                _wpnonce: wopgld_frontend_js_params.ajax_nonce,
                layout_type: layout_type,
                page_num: page_num,
                total_page: total_page,
                post_id: post_id,
                next_arrow: next_arrow,
                prev_arrow: prev_arrow

            },
            beforeSend: function(xhr) {
                selector.closest('.wopgld-pagination-block').find('.wopgld-ajax-loader').show();
            },
            success: function(response) {
                if (selector.closest('.wopgld-main-product-wrapper').find('.wopgld-filter-wrap').length > 0) {
                    selector.closest('.wopgld-main-product-wrapper').find('.wopgld-filter-trigger[data-filter-key="wopgld-filter-all"]').click();
                }

                selector.closest('.wopgld-pagination-block').find('.wopgld-ajax-loader').hide();
                if (layout_type === 'masonry') {
                    var masonary_id = selector.closest('.wopgld-masonry-wrapper').find('.wopgld-masonry-item-wrap').data('masonary-id');
                    //wopgld_masonary_obj[masonary_id].isotope('destroy');
                    selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').html(response);
                    selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').imagesLoaded(function() {
                        $('.wopgld-masonry-item-wrap').isotope({
                            itemSelector: '.wopgld-masonry-item',
                            percentPosition: true,
                            masonry: {
                                columnWidth: '.wopgld-masonry-sizer',
                                horizontalOrder: true,
                                gutter: 0

                            }
                        });
                    });
                } else {

                    selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').html(response);
                }
                $('html, body').animate({
                    scrollTop: selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').offset().top - 200 //this will keep content positioned correctly, but you shouldn't need both a '+ 200' and '- 200' here. Adjust this value as needed.
                }, 900);
                var pagination_html = wopgld_build_pagination_html(page_num, total_page, post_id, layout_type, next_arrow, prev_arrow);
                selector.closest('.wopgld-main-product-wrapper').find('.wopgld-pagination-block ul').html(pagination_html);
                /*
                 * Add span to add to cart woocommerce
                 */
                $('.add_to_cart_button').each(function() {
                    var text = $(this).closest('.add_to_cart_button').html();
                    $(this).closest('.add_to_cart_button').html('<span class="wopgld-span">' + text + '</span>');
                });
            }
        });
    });
    /**
     * Next Page Pagination
     *
     * @since 1.0.0
     */
    $('body').on('click', '.wopgld-next-page,.wopgld-previous-page', function() {
        var selector = $(this);
        var layout_type = $(this).data('layout-type');
        var post_id = $(this).data('post-id');
        var total_page = $(this).data('total-page');
        var current_page = $(this).closest('.wopgld-pagination-block').find('.wopgld-current-page').data('page-number');
        var next_page = parseInt(current_page) + 1;
        var previous_page = parseInt(current_page) - 1;
        var next_arrow = $(this).data('next-arrow');
        var prev_arrow = $(this).data('prev-arrow');
        if (selector.hasClass('wopgld-previous-page')) {
            current_page = previous_page;
        } else {
            current_page = next_page;
        }

        $.ajax({
            type: 'post',
            url: wopgld_frontend_js_params.ajax_url,
            data: {
                action: 'wopgld_pagination_action',
                _wpnonce: wopgld_frontend_js_params.ajax_nonce,
                layout_type: layout_type,
                page_num: current_page,
                post_id: post_id
            },
            beforeSend: function(xhr) {
                selector.closest('.wopgld-pagination-block').find('.wopgld-ajax-loader').show();
            },
            success: function(response) {
                if (selector.closest('.wopgld-main-product-wrapper').find('.wopgld-filter-wrap').length > 0) {
                    selector.closest('.wopgld-main-product-wrapper').find('.wopgld-filter-trigger[data-filter-key="wopgld-filter-all"]').click();
                }
                selector.closest('.wopgld-pagination-block').find('.wopgld-ajax-loader').hide();
                if (layout_type === 'masonry') {
                    var masonary_id = selector.closest('.wopgld-masonry-wrapper').find('.wopgld-masonry-item-wrap').data('masonary-id');
                    // wopgld_masonary_obj[masonary_id].isotope('destroy');
                    selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').html(response);
                    selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').imagesLoaded(function() {
                        $('.wopgld-masonry-item-wrap').isotope({
                            itemSelector: '.wopgld-masonry-item',
                            percentPosition: true,
                            masonry: {
                                columnWidth: '.wopgld-masonry-sizer',
                                horizontalOrder: true,
                                gutter: 0

                            }
                        });
                    });
                } else {
                    selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').html(response);
                }
                $('html, body').animate({
                    scrollTop: selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').offset().top - 200 //this will keep content positioned correctly, but you shouldn't need both a '+ 200' and '- 200' here. Adjust this value as needed.
                }, 900);
                var pagination_html = wopgld_build_pagination_html(current_page, total_page, post_id, layout_type, next_arrow, prev_arrow);
                selector.closest('.wopgld-main-product-wrapper').find('.wopgld-pagination-block ul').html(pagination_html);
                /*
                 * Add span to add to cart woocommerce
                 */
                $('.add_to_cart_button').each(function() {
                    var text = $(this).closest('.add_to_cart_button').html();
                    $(this).closest('.add_to_cart_button').html('<span class="wopgld-span">' + text + '</span>');
                });
            }
        });
    });
    /**
     * Load More Action
     *
     * @since 1.0.0
     */
    $('.wopgld-load-more-trigger').click(function() {
        var selector = $(this);
        var masonary_id = selector.closest('.wopgld-masonry-wrapper').find('.wopgld-masonry-item-wrap').data('masonary-id');
        var layout_type = $(this).data('layout-type');
        var page_num = $(this).data('page-number');
        var post_id = $(this).data('post-id');
        var total_page = $(this).data('total-page');
        var next_page = parseInt(page_num) + 1;
        if (next_page <= total_page) {
            $.ajax({
                type: 'post',
                url: wopgld_frontend_js_params.ajax_url,
                data: {
                    action: 'wopgld_pagination_action',
                    _wpnonce: wopgld_frontend_js_params.ajax_nonce,
                    layout_type: layout_type,
                    page_num: next_page,
                    post_id: post_id
                },
                beforeSend: function(xhr) {
                    selector.hide();
                    selector.closest('.wopgld-load-more-block').find('.wopgld-ajax-loader').show();
                },
                success: function(response) {

                    selector.data('page-number', next_page);
                    selector.closest('.wopgld-load-more-block').find('.wopgld-ajax-loader').hide();
                    if (selector.closest('.wopgld-main-product-wrapper').find('.wopgld-filter-wrap').length > 0) {
                        selector.closest('.wopgld-main-product-wrapper').find('.wopgld-filter-trigger[data-filter-key="wopgld-filter-all"]').click();
                    }

                    if (layout_type === 'masonry') {
                        var $items = $(response);
                        //alert($items);
                        wopgld_masonary_obj[masonary_id].append($items).isotope('appended', $items);
                        wopgld_masonary_obj[masonary_id].imagesLoaded(function() {
                        })
                                .done(function(instance) {
                                    console.log('all images successfully loaded');
                                    selector.closest('.ap_pagination').find('.ap_wait_loader').hide();
                                    selector.show();
                                    wopgld_masonary_obj[masonary_id].isotope('reloadItems').isotope();
                                })
                                .fail(function() {
                                    console.log('all images loaded, at least one is broken');
                                    wopgld_masonary_obj[masonary_id].isotope('reloadItems').isotope();
                                })
                                .progress(function(instance, image) {
                                });
                    } else if (layout_type === 'timeline') {
                        selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section .wopgld-blog-cover').append(response);
                    } else {
                        // selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').html(response);
                        selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').append(response);
                    }

                    if (next_page === total_page) {
                        selector.remove();
                    } else {

                        selector.show();
                    }
                    /*
                     * Add span to add to cart woocommerce
                     */
                    $('.add_to_cart_button').each(function() {
                        var text = $(this).closest('.add_to_cart_button').html();
                        $(this).closest('.add_to_cart_button').html('<span class="wopgld-span">' + text + '</span>');
                    });
                }
            });
        } else {
            selector.remove();
        }

    });
    /**
     *Infinite Scroll Action
     *
     * @since 1.0.0
     */
    var infinte_load = 0;
    $('.wopgld-infinite-load-trigger').click(function() {
        var selector = $(this);
        var masonary_id = selector.closest('.wopgld-masonry-wrapper').find('.wopgld-masonry-item-wrap').data('masonary-id');
        var layout_type = $(this).data('layout-type');
        var page_num = $(this).data('page-number');
        var post_id = $(this).data('post-id');
        var total_page = $(this).data('total-page');
        var next_page = parseInt(page_num) + 1;
        if (next_page <= total_page) {
            $.ajax({
                type: 'post',
                url: wopgld_frontend_js_params.ajax_url,
                data: {
                    action: 'wopgld_pagination_action',
                    _wpnonce: wopgld_frontend_js_params.ajax_nonce,
                    layout_type: layout_type,
                    page_num: next_page,
                    post_id: post_id
                },
                beforeSend: function(xhr) {
                    infinte_load = 1;
                    selector.hide();
                    selector.closest('.wopgld-infinite-load').find('.wopgld-infinite-loader').show();
                },
                success: function(response) {
                    infinte_load = 0;
                    selector.data('page-number', next_page);
                    selector.closest('.wopgld-infinite-load').find('.wopgld-infinite-loader').hide();
                    if (selector.closest('.wopgld-main-product-wrapper').find('.wopgld-filter-wrap').length > 0) {
                        selector.closest('.wopgld-main-product-wrapper').find('.wopgld-filter-trigger[data-filter-key="wopgld-filter-all"]').click();
                    }

                    if (layout_type === 'masonry') {
                        var $items = $(response);
                        //alert($items);
                        wopgld_masonary_obj[masonary_id].append($items).isotope('appended', $items);
                        wopgld_masonary_obj[masonary_id].imagesLoaded(function() {
                        })
                                .done(function(instance) {
                                    console.log('all images successfully loaded');
                                    selector.closest('.ap_pagination').find('.ap_wait_loader').hide();
                                    selector.show();
                                    wopgld_masonary_obj[masonary_id].isotope('reloadItems').isotope();
                                })
                                .fail(function() {
                                    console.log('all images loaded, at least one is broken');
                                    wopgld_masonary_obj[masonary_id].isotope('reloadItems').isotope();
                                })
                                .progress(function(instance, image) {
                                });
                    } else if (layout_type === 'timeline') {
                        selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section .wopgld-blog-cover').append(response);
                    } else {
                        // selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').html(response);
                        selector.closest('.wopgld-main-product-wrapper').find('.wopgld-layout-' + layout_type + '-section').append(response);
                    }

                    if (next_page === total_page) {
                        selector.remove();
                    } else {

                        selector.show();
                    }
                    /*
                     * Add span to add to cart woocommerce
                     */
                    $('.add_to_cart_button').each(function() {
                        var text = $(this).closest('.add_to_cart_button').html();
                        $(this).closest('.add_to_cart_button').html('<span class="wopgld-span">' + text + '</span>');
                    });
                }
            });
        } else {
            selector.remove();
        }
    });
    /**
     *  Infinte scroll Implementation
     * */

    $(window).scroll(function() {
        var top = ($('.wopgld-infinite-scroll-wrapper').offset() || {"top": NaN}).top;
        var nav = $('.wopgld-infinite-scroll-wrapper');
        if (!isNaN(top)) {
            if ($(window).scrollTop() >= nav.offset().top + nav.outerHeight() - window.innerHeight) {
                if (infinte_load === 0) {
                    $('.wopgld-infinite-load-trigger:first').trigger('click');
                }
            }
        }

    });
    /*
     *
     * @Masonary intialization
     */
    var wopgld_masonary_obj = [];
    $('.wopgld-masonry-item-wrap').each(function() {
        var $selector = $(this);
        var masonary_id = $(this).data('masonary-id');
        wopgld_masonary_obj[masonary_id] = $selector.imagesLoaded(function() {
            wopgld_masonary_obj[masonary_id].isotope({
                itemSelector: '.wopgld-masonry-item',
                percentPosition: true,
                masonry: {
                    columnWidth: '.wopgld-masonry-sizer',
                    horizontalOrder: true,
                    gutter: 0


                }
            });
        });
    });
    /*
     * Filter template implementation
     */
    $('.wopgld-filter-trigger').click(function() {
        var selector = $(this);
        var filter_key = selector.data('filter-key');
        var layout_type = selector.data('layout-type');
        selector.closest('.wopgld-filter-wrap').find('.wopgld-filter-trigger').removeClass('wopgld-active-filter');
        selector.addClass('wopgld-active-filter');
        if (layout_type === 'grid') {
            if (filter_key === 'wopgld-filter-all') {
                selector.closest('.wopgld-main-product-wrapper').find('.wopgld-inner-wrap').removeClass('wopgld-hidden-grid').addClass('wopgld-visible-grid').show();
            } else {
                selector.closest('.wopgld-main-product-wrapper').find('.wopgld-inner-wrap').addClass('wopgld-hidden-grid').removeClass('wopgld-visible-grid').hide();
                selector.closest('.wopgld-main-product-wrapper').find('.' + filter_key).removeClass('wopgld-hidden-grid').addClass('wopgld-visible-grid').show();
            }
        } else if (layout_type === 'masonry') {
            filterValue = (filter_key === 'all') ? '*' : '.' + filter_key;
            var masonary_id = selector.closest('.wopgld-masonry-wrapper').find('.wopgld-masonry-item-wrap').data('masonary-id');
            wopgld_masonary_obj[masonary_id].isotope({filter: filterValue});
        }
    });
    //Slider Layout
//    var wopgld_slider = [];
//    $(".wopgld-layout-slider-section").each(function() {
//        var id = $(this).data('id');
//        var selector = $(this);
//        var a = 1;
//        var controls = $(this).data('controls');
//        var auto = $(this).data('auto');
//        var speed = $(this).data('speed');
//        var pager = $(this).data('pager');
//        var template = $(this).data('template');
//        var next_text = '<i class="fa fa-angle-right" aria-hidden="true"></i>';
//        var pre_text = '<i class="fa fa-angle-left" aria-hidden="true"></i>';
//        //alert(speed);
//        wopgld_slider[id] = $(this).bxSlider({
//            auto: auto,
//            control: controls,
//            pause: 6000,
//            speed: speed,
//            pager: pager,
//            infiniteLoop: true,
//            nextText: next_text,
//            prevText: pre_text,
//            adaptiveHeight: true,
//            autoHover: true,
//            useCSS: false,
//            onSliderLoad: function(currentSlideHtmlObject) {
//                // var a = currentSlideHtmlObject;
//
//                if (template === 'template-1') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-circle-content').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-circle-content').eq(+a).addClass('animated fadeIn');
//                    }, 500
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+a).addClass('animated slideInUp');
//                    }, 700
//                            );
//                } else if (template === 'template-2') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-side-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-side-wrap').eq(+a).addClass('animated slideInDown');
//                    }, 600
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+a).addClass('animated slideInUp');
//                    }, 400
//                            );
//                } else if (template === 'template-3' || template === 'template-4') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+a).addClass('animated zoomIn');
//                    }, 400
//                            );
//                } else if (template === 'template-5') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+a).addClass('animated slideInLeft');
//                    }, 400
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+a).addClass('animated slideInUp');
//                    }, 500
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-below-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-below-wrap').eq(+a).addClass('animated slideInRight');
//                    }, 400
//                            );
//                } else if (template === 'template-6') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+a).addClass('animated slideInLeft');
//                    }, 400
//                            );
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+a).addClass('animated slideInRight');
//                    }, 400
//                            );
//                } else {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+a).addClass('animated zoomIn');
//                    }, 400
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+a).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+a).addClass('animated slideInUp');
//                    }, 500
//                            );
//                }
//            },
//            onSlideAfter: function(currentSlideNumber, totalSlideQty, currentSlideHtmlObject) {
//                var acurrent = currentSlideHtmlObject + 1;
//                if (template === 'template-1') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-circle-content').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-circle-content').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-circle-content').eq(+acurrent).addClass('animated fadeIn');
//                    }, 500
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).addClass('animated slideInUp');
//                    }, 700
//                            );
//                } else if (template === 'template-2') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-side-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-side-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-side-wrap').eq(+acurrent).addClass('animated slideInDown');
//                    }, 600
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).addClass('animated slideInUp');
//                    }, 400
//                            );
//                } else if (template === 'template-3' || template === 'template-4') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+acurrent).addClass('animated zoomIn');
//                    }, 400
//                            );
//                } else if (template === 'template-5') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).addClass('animated slideInLeft');
//                    }, 400
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).addClass('animated slideInUp');
//                    }, 500
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-below-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-below-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-below-wrap').eq(+acurrent).addClass('animated slideInRight');
//                    }, 400
//                            );
//                } else if (template === 'template-6') {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').eq(+acurrent).addClass('animated slideInLeft');
//                    }, 400
//                            );
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).addClass('animated slideInRight');
//                    }, 400
//                            );
//                } else {
//                    setTimeout(function() {
//
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').eq(+acurrent).addClass('animated zoomIn');
//                    }, 400
//                            );
//                    setTimeout(function() {
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+acurrent).removeClass('wopgld-hidden');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+acurrent).removeClass('animated fadeOut');
//                        selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').eq(+acurrent).addClass('animated slideInUp');
//                    }, 500
//                            );
//                }
//
//            },
//            onSlideBefore: function(currentSlideHtmlObject) {
//                // var acurrent = currentSlideHtmlObject + 1;
//                if (template === 'template-1') {
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-circle-content').removeClass('animated fadeIn');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').removeClass('animated slideInUp');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-circle-content').addClass('animated fadeOut');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').addClass('animated fadeOut');
//                } else if (template === 'template-2') {
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-side-wrap').removeClass('animated slideInDown');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').removeClass('animated slideInUp');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-side-wrap').addClass('animated fadeOut');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').addClass('animated fadeOut');
//                } else if (template === 'template-3' || template === 'template-4') {
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').removeClass('animated zoomIn');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').addClass('animated fadeOut');
//                } else if (template === 'template-5') {
//
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').removeClass('animated slideInLeft');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').removeClass('animated slideInUp');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-below-wrap').removeClass('animated slideInRight');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').addClass('animated fadeOut');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').addClass('animated fadeOut');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-below-wrap').addClass('animated fadeOut');
//                } else if (template === 'template-6') {
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').removeClass('animated slideInLeft');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-image-hover-wrap').addClass('animated fadeOut');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').removeClass('animated slideInRight');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').addClass('animated fadeOut');
//                } else {
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').removeClass('animated zoomIn');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').removeClass('animated slideInUp');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-top-wrap').addClass('animated fadeOut');
//                    selector.closest('.wopgld-layout-slider-section').find('.wopgld-detail-inner-wrap').addClass('animated fadeOut');
//                }
//            }
//
//        });
//    });
    //Carousel layout
//    var wopgld_carousel = [];
//    $(".wopgld-layout-carousel-section").each(function() {
//        var id = $('.wopgld-main-product-wrapper').data('id');
//        var column = $(this).data('column');
//        var controls = $(this).data('controls');
//        var auto = $(this).data('auto');
//        var speed = $(this).data('speed');
//        var pager = $(this).data('pager');
//        var width = $(this).data('width');
//        var next_text = '<i class="fa fa-angle-right" aria-hidden="true"></i>';
//        var pre_text = '<i class="fa fa-angle-left" aria-hidden="true"></i>';
//        var margin = 15;
//        if (jQuery(window).width() >= 981) {
//            var itemcolumn = column;
//            var slidew = width;
//            var smargin = margin;
//        } else if (jQuery(window).width() <= 980 && jQuery(window).width() >= 801) {
//            var itemcolumn = 3;
//            var slidew = 300;
//            var smargin = margin;
//        } else if (jQuery(window).width() <= 800 && jQuery(window).width() >= 641) {
//            var itemcolumn = 2;
//            var slidew = 240;
//            var smargin = margin;
//        } else if (jQuery(window).width() <= 640 && jQuery(window).width() >= 320) {
//            var itemcolumn = 1;
//            var slidew = 350;
//            var smargin = 0;
//        }
//
//        wopgld_carousel[id] = $(this).bxSlider({
//            minSlides: 1,
//            maxSlides: itemcolumn,
//            moveSlides: 1,
//            pager: pager,
//            slideWidth: slidew,
//            slideMargin: smargin,
//            auto: auto,
//            controls: controls,
//            speed: speed,
//            nextText: next_text,
//            prevText: pre_text
//
//        });
//    });
    /*
     * Wishlist Functionality
     */
    $('body').on('click', '.add_to_wishlist', function() {
        $(this).closest('.wopgld-wishlist-wrap').find('.ajax-loading').removeAttr("style", "display: none !important");
        $(this).closest('.wopgld-wishlist-wrap').find('.wopgld-heart').removeClass("fa-heart-o");
    });
    /*
     * Add span to View Cart woocommerce
     */
    $('body').on('click', '.add_to_cart_button', function() {
        $(document).ajaxComplete(function() {
            $('.added_to_cart').each(function() {
                $('.added_to_cart').html('<span class="wopgld-span">View Cart</span>');
            });
        });
    });
    /*
     * Add span to add to cart woocommerce
     */
    $('.add_to_cart_button').each(function() {
        var text = $(this).closest('.add_to_cart_button').html();
        $(this).closest('.add_to_cart_button').html('<span class="wopgld-span">' + text + '</span>');
    });
    /*
     * Get Variable price option for EDD
     */

    $('body').on('change', '.wopgld-variable-price', function() {

        var price_id = $(this).val();
        var id = $(this).closest('.wopgld-price').find('.wopgld_price_options').data('id');
        var link = $(this).closest('.wopgld-price').find('.wopgld_price_options').data('link');
        $(this).closest('.wopgld-inner-wrap').find('.wopgld-edd-price').attr("href", '' + link + '?edd_action=add_to_cart&download_id=' + id + '&edd_options[price_id]=' + price_id + '');
        //  alert(a);

    });
    /*
     * Lightbox function
     */
    function wopgld_slider_lightbox() {
        $(".wopgld-lightbox-image-wrapper").each(function() {
            var selector = $(this);
            var id = $(this).data('id');
            var next_text = '<i class="fa fa-angle-right" aria-hidden="true"></i>';
            var pre_text = '<i class="fa fa-angle-left" aria-hidden="true"></i>';
            wopgld_lightbox_slider[id] = $(this).bxSlider({
                auto: false,
                control: true,
                speed: 2000,
                pager: true,
                infiniteLoop: true,
                nextText: next_text,
                prevText: pre_text,
                mode: 'horizontal',
                pagerCustom: '#wopgld-pager-' + id,
                useCSS: false,
                onSlideBefore: function($slideElement, oldIndex, newIndex) {
                    selector.closest('.wopgld-each-thumb').find('.active').removeClass("active");
                    selector.closest('.wopgld-each-thumb').find('a[data-slide-index="' + newIndex + '"]').addClass("active");
                    var slider = wopgld_thumb_slider[id];
                    if (slider.getSlideCount() - newIndex >= count)
                        slider.goToSlide(newIndex);
                    else
                        slider.goToSlide(slider.getSlideCount() - count);
                }
            });
        });
        var count = 0;
        $(".wopgld-thumbnail-slider").each(function() {
            var id = $(this).data('id');
            var next_text = '<i class="fa fa-angle-right" aria-hidden="true"></i>';
            var pre_text = '<i class="fa fa-angle-left" aria-hidden="true"></i>';
            wopgld_thumb_slider[id] = $(this).bxSlider({
                minSlides: 1,
                maxSlides: 4,
                slideWidth: 100,
                slideMargin: 10,
                moveSlides: 1,
                auto: false,
                pager: false,
                infiniteLoop: true,
                nextText: next_text,
                prevText: pre_text
            });
        });
    }

    /*
     * Popup Images Gallery
     */

    $('body').on('click', '.wopgld-content-lightbox', function() {
        var layout = $(this).closest('.wopgld-main-product-wrapper').data('layout');
//        if (layout === 'carousel' || layout === 'slider') {
//            $(".wopgld-display-popup").addClass('wopgld-active');
//            var selector = $(this);
//            if (layout === 'carousel') {
//                var post_id = selector.closest('.wopgld-inner-wrap').data('post_id');
//                var shortcode_id = selector.closest('.wopgld-inner-wrap').data('shortcode_id');
//            } else {
//                var post_id = selector.closest('.wopgld-slider-inner-wrap').data('post_id');
//                var shortcode_id = selector.closest('.wopgld-slider-inner-wrap').data('shortcode_id');
//            }
//            $.ajax({
//                url: wopgld_frontend_js_params.ajax_url,
//                data: {
//                    post_id: post_id,
//                    shortcode_id: shortcode_id,
//                    _wpnonce: wopgld_frontend_js_params.ajax_nonce,
//                    action: 'wopgld_view_lightbox',
//                    beforeSend: function() {
//                        $('.wopgld-lightbox-loader').show();
//                    }
//                },
//                type: "POST",
//                success: function(response) {
//                    $('.wopgld-lightbox-loader').hide();
//                    $(".wopgld-display-popup").html(response);
//                    var wopgld_lightbox_slider = [];
//                    var wopgld_thumb_slider = [];
//                    wopgld_slider_lightbox();
//                    $('.wopgld-lightbox-detail-wrap').mCustomScrollbar({
//                        theme: 'dark-3',
//                        mouseWheel: {enable: true},
//                        axis: 'y'
//                    });
//                }
//
//            });
//        }
        if (layout === 'masonry')
        {
            $('.wopgld-masonry-item').removeClass('wopgld-active-lightbox');
            $(this).closest('.wopgld-masonry-item').addClass('wopgld-active-lightbox');
        } else {
            $(this).closest('.wopgld-inner-wrap').find('.wopgld-lightbox-detail-wrap').fadeIn(500);
            $('.wopgld-inner-wrap').removeClass('wopgld-active-lightbox');
            $(this).closest('.wopgld-inner-wrap').addClass('wopgld-active-lightbox');
        }

    });
    /*
     * Popup close
     *
     */
    $('body').on('click', '.wopgld-close-lightbox', function() {
        var layout = $('.wopgld-content-lightbox').closest('.wopgld-main-product-wrapper').data('layout');
        if (layout === 'carousel' || layout === 'slider') {
            $(".wopgld-display-popup").removeClass('wopgld-active');
            $(this).closest('.wopgld-lightbox-detail-wrap').fadeOut(500);
        } else if (layout === 'masonry') {
            $('.wopgld-masonry-item').removeClass('wopgld-active-lightbox');
        } else {
            $('.wopgld-inner-wrap').removeClass('wopgld-active-lightbox');
        }

    });
    /*
     * Lightbox Slider Images
     */
    var wopgld_lightbox_slider = [];
    var wopgld_thumb_slider = [];
    $(".wopgld-lightbox-image-wrapper").each(function() {
        var selector = $(this);
        var id = $(this).data('id');
        var next_text = '<i class="fa fa-angle-right" aria-hidden="true"></i>';
        var pre_text = '<i class="fa fa-angle-left" aria-hidden="true"></i>';
        wopgld_lightbox_slider[id] = $(this).bxSlider({
            auto: false,
            control: true,
            speed: 2000,
            pager: true,
            infiniteLoop: true,
            nextText: next_text,
            prevText: pre_text,
            mode: 'horizontal',
            pagerCustom: '#wopgld-pager-' + id,
            useCSS: false,
            onSlideBefore: function($slideElement, oldIndex, newIndex) {
                selector.closest('.wopgld-each-thumb').find('.active').removeClass("active");
                selector.closest('.wopgld-each-thumb').find('a[data-slide-index="' + newIndex + '"]').addClass("active");
                var slider = wopgld_thumb_slider[id];
                if (slider.getSlideCount() - newIndex >= count)
                    slider.goToSlide(newIndex);
                else
                    slider.goToSlide(slider.getSlideCount() - count);
            }
        });
    });
    var count = 0;
    $(".wopgld-thumbnail-slider").each(function() {
        var id = $(this).data('id');
        var next_text = '<i class="fa fa-angle-right" aria-hidden="true"></i>';
        var pre_text = '<i class="fa fa-angle-left" aria-hidden="true"></i>';
        wopgld_thumb_slider[id] = $(this).bxSlider({
            minSlides: 1,
            maxSlides: 4,
            slideWidth: 100,
            slideMargin: 10,
            moveSlides: 1,
            auto: false,
            pager: false,
            infiniteLoop: true,
            nextText: next_text,
            prevText: pre_text
        });
    });
    /*
     * Scroll Configuration
     */

    $('.wopgld-lightbox-detail-wrap').mCustomScrollbar({
        theme: 'dark-3',
        mouseWheel: {enable: true},
        axis: 'y'


    });
    /*
     * Swap effect on images
     */
//
//    $('body').on('hover', '.wopgld-inner-wrap', function() {
//        var swap = $(this).find('.wopgld-swap-image').data('swap');
//        $(this).find('.wopgld-swap-image').fadeIn(100).attr('src', swap).fadeIn(200);
//    });
//    $('body').on('mouseleave', '.wopgld-inner-wrap', function() {
//        var original = $(this).find('.wopgld-swap-image').data('original');
//        $(this).find('.wopgld-swap-image').attr('src', original).fadeIn('slow');
//    });
//    $('body').on('hover', '.wopgld-masonry-item-inner', function() {
//        var swap = $(this).find('.wopgld-swap-image').data('swap');
//        $(this).find('.wopgld-swap-image').fadeIn(100).attr('src', swap).fadeIn(200);
//    });
//    $('body').on('mouseleave', '.wopgld-masonry-item-inner', function() {
//        var original = $(this).find('.wopgld-swap-image').data('original');
//        $(this).find('.wopgld-swap-image').attr('src', original).fadeIn('slow');
//    });
    /*
     * WooCommerce Disable link for Variable Price functionality
     *
     */
    $('body').on('click', '.product_type_variable', function() {
        event.preventDefault();
        var selector = $(this);
        var post_id = selector.closest('.add_to_cart_button').data('product_id');
        $.ajax({
            url: wopgld_frontend_js_params.ajax_url,
            data: {
                post_id: post_id,
                _wpnonce: wopgld_frontend_js_params.ajax_nonce,
                action: 'wopgld_variable_attribute',
                beforeSend: function() {
                    $('.wopgld-lightbox-loader').show();
                }
            },
            type: "POST",
            success: function(response) {
                //alert(response);
                $('.wopgld-lightbox-loader').hide();
                $(".wopgld-attributes-container").html(response);
            },

            complete: function() {
                loadVariationScript();
            }

        });
        event.preventDefault();
    });
    $('body').on('click', '.wopgld-close-variation', function() {
        $(this).closest('.wopgld-attributes-container').find('.wopgld-variation-container').fadeOut();
    });
    $('body').on('click', '.wopgld-share-container', function() {
        //    $(this).closest('.wopgld-detail-side-wrap').find('.wopgld-share-outer-wrap').removeClass('wopgld-hidden');
        $(this).closest('.wopgld-detail-side-wrap').find('.wopgld-share-outer-wrap').animate({width: 'toggle'});
    });

    // Ajax add to cart
    $(document).on('click', '.variations_form .single_add_to_cart_button', function(e) {

        e.preventDefault();

        $variation_form = $(this).closest('.variations_form');
        var var_id = $variation_form.find('input[name=variation_id]').val();
        var product_id = $variation_form.find('input[name=product_id]').val();
        var quantity = $variation_form.find('input[name=quantity]').val();

        //attributes = [];
        $('.ajaxerrors').remove();
        var item = {},
                check = true;

        variations = $variation_form.find('select[name^=attribute]');

        /* Updated code to work with radio button - mantish - WC Variations Radio Buttons - 8manos */
        if (!variations.length) {
            variations = $variation_form.find('[name^=attribute]:checked');
        }

        /* Backup Code for getting input variable */
        if (!variations.length) {
            variations = $variation_form.find('input[name^=attribute]');
        }

        variations.each(function() {

            var $this = $(this),
                    attributeName = $this.attr('name'),
                    attributevalue = $this.val(),
                    index,
                    attributeTaxName;

            $this.removeClass('error');

            if (attributevalue.length === 0) {
                index = attributeName.lastIndexOf('_');
                attributeTaxName = attributeName.substring(index + 1);

                $this
                        //.css( 'border', '1px solid red' )
                        .addClass('required error')
                        //.addClass( 'barizi-class' )
                        .before('<div class="ajaxerrors"><p>Please select ' + attributeTaxName + '</p></div>')

                check = false;
            } else {
                item[attributeName] = attributevalue;
            }


        });

        if (!check) {
            return false;
        }

        var $thisbutton = $(this);

        if ($thisbutton.is('.variations_form .single_add_to_cart_button')) {

            $thisbutton.removeClass('added');
            $thisbutton.addClass('loading');

            var data = {
                action: 'woocommerce_add_to_cart_variable_rc',
                product_id: product_id,
                quantity: quantity,
                variation_id: var_id,
                variation: item
            };

            // Trigger event
            $('body').trigger('adding_to_cart', [$thisbutton, data]);

            // Ajax action
            $.post(wc_add_to_cart_params.ajax_url, data, function(response) {

                if (!response)
                    return;

                var this_page = window.location.toString();

                this_page = this_page.replace('add-to-cart', 'added-to-cart');

                if (response.error && response.product_url) {
                    window.location = response.product_url;
                    return;
                }

                if (wc_add_to_cart_params.cart_redirect_after_add === 'yes') {

                    window.location = wc_add_to_cart_params.cart_url;
                    return;

                } else {

                    $thisbutton.removeClass('loading');

                    var fragments = response.fragments;
                    var cart_hash = response.cart_hash;

                    // Block fragments class
                    if (fragments) {
                        $.each(fragments, function(key) {
                            $(key).addClass('updating');
                        });
                    }

                    // Block widgets and fragments
                    $('.shop_table.cart, .updating, .cart_totals').fadeTo('400', '0.6').block({
                        message: null,
                        overlayCSS: {
                            opacity: 0.6
                        }
                    });

                    // Changes button classes
                    $thisbutton.addClass('added');

                    // View cart text
                    if (!wc_add_to_cart_params.is_cart && $thisbutton.parent().find('.added_to_cart').size() === 0) {
                        $thisbutton.after(' <a href="' + wc_add_to_cart_params.cart_url + '" class="added_to_cart wc-forward" title="' +
                                wc_add_to_cart_params.i18n_view_cart + '">' + wc_add_to_cart_params.i18n_view_cart + '</a>');
                    }

                    // Replace fragments
                    if (fragments) {
                        $.each(fragments, function(key, value) {
                            $(key).replaceWith(value);
                        });
                    }

                    // Unblock
                    $('.widget_shopping_cart, .updating').stop(true).css('opacity', '1').unblock();

                    // Cart page elements
                    $('.shop_table.cart').load(this_page + ' .shop_table.cart:eq(0) > *', function() {

                        $('.shop_table.cart').stop(true).css('opacity', '1').unblock();

                        $(document.body).trigger('cart_page_refreshed');
                    });

                    $('.cart_totals').load(this_page + ' .cart_totals:eq(0) > *', function() {
                        $('.cart_totals').stop(true).css('opacity', '1').unblock();
                    });

                    // Trigger event so themes can refresh other areas
                    $(document.body).trigger('added_to_cart', [fragments, cart_hash, $thisbutton]);
                }
            });

            return false;

        } else {
            return true;
        }

    });

    function loadVariationScript() {
        var url = wopgld_object_name.templateUrl;
        //alert(url);
        $.getScript(url + '/assets/js/frontend/add-to-cart-variation.min.js');
        $.getScript(url + '/assets/js/frontend/add-to-cart-variation.js');
    }

    /*
     * List cantaloupe template
     */
    $('body').on('click', '.wopgld-buttons-collection-secondary', function() {
        $(this).closest('.wopgld-content-two-wrap').find('.wopgld-buttons-collection').toggleClass('wopgld-display-buttons');
        if ($('.wopgld-buttons-collection').hasClass('wopgld-display-buttons')) {
            var number_of_children = $(this).closest('.wopgld-content-two-wrap').find('.wopgld-buttons-collection-primary').children().length;
            if (number_of_children == 4) {
                var estimated_width = 160;
            } else {
                var estimated_width = ((number_of_children * 25) + ((number_of_children + 1) * 15));
            }
            $(this).closest('.wopgld-content-two-wrap').find('.wopgld-buttons-collection-primary').css("width", estimated_width);
        } else {
            $(this).closest('.wopgld-content-two-wrap').find('.wopgld-buttons-collection-primary').css('width', '0');
        }
    });
});